---
id: Windows
title: Building on Windows
tags:
  - Build Instructions
  - Compiling
  - Windows
---
# Build the Viewer on Windows

## Step 1: Install Requirements
### Required Software
* [Git for Windows](https://gitforwindows.org/ "Git for Windows downloads")
* [Python 3.10+](https://www.python.org/downloads/ "Python scripting language downloads") - **Be sure to "Add Python to PATH"**
* [Visual Studio 2022](https://visualstudio.microsoft.com/downloads/ "The Visual Studio 2022 suite download") - **Select "Desktop development with C++" workload**

### Optional Software 
If you're building 3rd party libs, cygwin is required
* [Cygwin](https://cygwin.com/install.html "Cygwin is optional for fmodstudio") - **Packages: bash, curl, wget, p7zip, zip, unzip**

### Intermediate Check

Confirm things are installed properly so far by opening a Powershell terminal and typing:

```
git --version
python --version
pip --version
```

If everything reported sensible values and not "Command not found" errors, then you are in good shape! If the `python --version` command returned an error you may need to add python to your `PATH`

## Step 2: Clone the viewer source

Open a Powershell terminal and clone the viewer source to a directory of your choosing without spaces or special characters.

```
cd C:\
mkdir secondlife
cd secondlife
git clone https://git.alchemyviewer.org/alchemy/alchemy-next.git
```

## Step 3: Setup a Python Virtual Environment

Once you've cloned the viewer source code change directories to the viewer source and create a Python virtual environment.

### Virtual Environment Creation
```
cd C:\secondlife\alchemy-next
python3 -m venv .venv
.\.venv\Scripts\Activate.ps1
```

### Package Installation
Then install the following packages using the command below.

* `cmake`
* `llbase`
* `llsd`
* `certifi`
* `autobuild`

```
pip install --upgrade cmake llbase llsd certifi autobuild
```

## Step 4: Generate Visual Studio Projects

The next steps will create a build environment with the required packages installed.

```
autobuild configure -c ReleaseOS -A64 -- -DLL_TESTS=OFF
```

## Step 5: Build the Viewer

The final command will start a viewer build and output to `build-vc-64\newview\Release`

```
autobuild build -c ReleaseOS -A64 --no-configure
```

## Optional Step: 3rd Party Libraries
Create a directory to house the 3rd party libraries.

```
mkdir thirdparty
cd thirdparty
```

### FMOD Studio
Clone the repo in your `thirdparty` directory

```
git clone https://git.alchemyviewer.org/alchemy/thirdparty/3p-fmodstudio
cd 3p-fmodstudio
```

Download fmod [FMOD Engine](https://www.fmod.com/) and place it inside the `C:\secondlife\thirdparty\3p-fmodstudio\fmodstudio\` directory

Build and package the library

```
autobuild build -A 64 --all
autobuild package -A 64
```

### Update autobuild.xml
Upon successful build and package, you should be left with a hash and a file path.
Navigate back to the main viewer source

```
cd C:\secondlife\alchemy-next
autobuild installables edit -a C:\secondlife\thirdparty\3p-fmodstudio\<file that was generated>
```
